==> haskell-concise-0.1.0.1-52-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concise
version: 0.1.0.1
id: concise-0.1.0.1-4CZZLacJOJyKxiuY679EGP
key: concise-0.1.0.1-4CZZLacJOJyKxiuY679EGP
license: BSD-3-Clause
copyright: Copyright (C) 2016  Fraser Tweedale
maintainer: frase@frase.id.au
author: Fraser Tweedale
homepage: https://github.com/frasertweedale/hs-concise
synopsis: Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.
category: Data, Lenses
abi: 10df2a2906d1844d19a7b6d8c14bc3d3
exposed: True
exposed-modules:
    Control.Lens.Cons.Extras
import-dirs: /usr/lib/ghc-8.4.3/site-local/concise-0.1.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/concise-0.1.0.1
hs-libraries: HSconcise-0.1.0.1-4CZZLacJOJyKxiuY679EGP
depends:
    base-4.11.1.0 lens-4.17-46TWctpZkRBHUbD4jUgMJb text-1.2.3.0
    bytestring-0.10.8.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             lens-4.17-46TWctpZkRBHUbD4jUgMJb=63a83ba94cfecc6580687b8535602d48
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
haddock-interfaces: /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html: /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concise-0.1.0.1-56-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concise
version: 0.1.0.1
id: concise-0.1.0.1-CsVvLHuYIvhAVAaX9CFBOG
key: concise-0.1.0.1-CsVvLHuYIvhAVAaX9CFBOG
license: BSD-3-Clause
copyright: Copyright (C) 2016  Fraser Tweedale
maintainer: frase@frase.id.au
author: Fraser Tweedale
homepage: https://github.com/frasertweedale/hs-concise
synopsis: Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.
category: Data, Lenses
abi: 05253df85e097f649af576a5f3baaa05
exposed: True
exposed-modules:
    Control.Lens.Cons.Extras
import-dirs: /usr/lib/ghc-8.4.3/site-local/concise-0.1.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/concise-0.1.0.1
hs-libraries: HSconcise-0.1.0.1-CsVvLHuYIvhAVAaX9CFBOG
depends:
    base-4.11.1.0 lens-4.17-LxcltwM7qPcDQIAMOmNPQC text-1.2.3.0
    bytestring-0.10.8.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             lens-4.17-LxcltwM7qPcDQIAMOmNPQC=99b1443fd2d1e52c81bb44d3da89599c
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
haddock-interfaces: /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html: /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
